"""
Demo scripts and examples for Conscious Bridge Law.
"""

from .arabic_context import arabic_demo
from .mixed_language import mixed_language_demo
from .philosophical_queries import philosophy_demo
from .web_demo import web_demo
from .advanced_simulation import advanced_simulation
from .multi_language_demo import multi_language_demo
from .data_analysis_demo import data_analysis_demo

__all__ = [
    "arabic_demo",
    "mixed_language_demo", 
    "philosophy_demo",
    "web_demo",
    "advanced_simulation",
    "multi_language_demo",
    "data_analysis_demo",
]